@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::AnyThing;
-$Config::Model::AnyThing::VERSION = '2.066';
+$Config::Model::AnyThing::VERSION = '2.067';
 use Mouse;
 
 # FIXME: must cleanup warp mechanism to implement this
@@ -24,7 +24,13 @@ my $change_logger = get_logger("Anything::Change");
 
 has element_name => ( is => 'ro', isa => 'Str' );
 has parent       => ( is => 'ro', isa => 'Config::Model::Node', weak_ref => 1 );
-has instance     => ( is => 'ro', isa => 'Config::Model::Instance', weak_ref => 1 );
+
+has instance     => (
+    is => 'ro',
+    isa => 'Config::Model::Instance',
+    weak_ref => 1,
+    handles => [qw/show_message/]
+);
 
 # needs_check defaults to 1 to trap undef mandatory values
 has needs_check => ( is => 'rw', isa => 'Bool', default => 1 );
@@ -627,7 +633,7 @@ Config::Model::AnyThing - Base class for configuration tree item
 
 =head1 VERSION
 
-version 2.066
+version 2.067
 
 =head1 SYNOPSIS
 
@@ -851,6 +857,10 @@ internal parameter.
 
 =back
 
+=head2 show_message( string )
+
+Forwarded to L<Config::Model::Instance/"show_message( string )">.
+
 =head2 model_searcher ()
 
 Returns an object dedicated to search an element in the configuration
