@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Any;
-$Config::Model::Backend::Any::VERSION = '2.066';
+$Config::Model::Backend::Any::VERSION = '2.067';
 use Carp;
 use strict;
 use warnings;
@@ -26,7 +26,8 @@ has 'node' => (
     is       => 'ro',
     isa      => 'Config::Model::Node',
     weak_ref => 1,
-    required => 1
+    required => 1,
+    handles => ['show_message'],
 );
 
 sub suffix {
@@ -170,7 +171,7 @@ Config::Model::Backend::Any - Virtual class for other backends
 
 =head1 VERSION
 
-version 2.066
+version 2.067
 
 =head1 SYNOPSIS
 
@@ -265,6 +266,14 @@ Whether the backend supports to read and write annotation. Default is
 
 =head1 Methods
 
+=head2 node
+
+Return the node (a L<Config::Model::Node>) holding this backend.
+
+=head2 show_message( string )
+
+Show a message to STDOUT (unless overridden). Delegated to L<Config::Model::Instance/"show_message( string )">.
+
 =head2 read_global_comments( lines , comment_char)
 
 Read the global comments (i.e. the first block of comments until the first blank or non comment line) and
