@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Instance;
-$Config::Model::Instance::VERSION = '2.066';
+$Config::Model::Instance::VERSION = '2.067';
 #use Scalar::Util qw(weaken) ;
 
 use 5.10.1;
@@ -160,7 +160,7 @@ sub has_warning {
 }
 
 has on_change_cb => (
-    is  => 'ro',
+    is  => 'rw',
     traits    => ['Code'],
     isa       => 'CodeRef',
     default   => sub { sub { } },
@@ -168,7 +168,7 @@ has on_change_cb => (
 
 has on_message_cb => (
     traits    => ['Code'],
-    is        => 'ro',
+    is        => 'rw',
     isa       => 'CodeRef',
     default   => sub { sub { say @_; } },
     handles   => {
@@ -496,7 +496,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.066
+version 2.067
 
 =head1 SYNOPSIS
 
