@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::SimpleUI;
-$Config::Model::SimpleUI::VERSION = '2.066';
+$Config::Model::SimpleUI::VERSION = '2.067';
 use Carp;
 use strict;
 use warnings;
@@ -63,11 +63,11 @@ my $desc_sub = sub {
 
 my $ll_sub = sub {
     my $self = shift;
-    my $elt  = shift // '';
+    my $elt  = shift ;
 
     my $obj = $self->{current_node};
     my $res ;
-    if ($elt =~ /\*/) {
+    if (defined $elt and $elt =~ /\*/) {
         $elt =~ s/\*/.*/g;
         $res = $obj->describe( pattern => qr/^$elt$/, check => 'no' );
     }
@@ -282,7 +282,7 @@ Config::Model::SimpleUI - Simple interface for Config::Model
 
 =head1 VERSION
 
-version 2.066
+version 2.067
 
 =head1 SYNOPSIS
 
